/*
 * Java-Gnome Bindings Library
 *
 * Copyright 1998-2004 the Java-Gnome Team, all rights reserved.
 *
 * The Java-Gnome bindings library is free software distributed under
 * the terms of the GNU Library General Public License version 2.
 */

package org.gnu.gdk;

import org.gnu.glib.Handle;

/**
 *
 */
public class Bitmap extends Drawable 
{
	
	public Bitmap(Handle handle){
		super(handle);
	}
	
	/**
	 * Creates a new <code>Bitmap</code> from data in XBM format.
	 */
	public Bitmap(Window window,byte data[],int width,int height){
		super(Bitmap.gdk_bitmap_create_from_data(window.getHandle(),data,width,height));
	}
	/**
	 * Creates a new <code>Bitmap</code> from data in XBM format.
	 */
	public Bitmap(byte data[],int width,int height){
		super(Bitmap.gdk_bitmap_create_from_data(null,data,width,height));
	}

    native static final protected Handle gdk_bitmap_create_from_data (Handle window, byte[] data, int 
        width, int height);
}

